"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initIndicator = void 0;
var electron_1 = require("electron");
var ipc_events_const_1 = require("./shared-with-frontend/ipc-events.const");
var get_settings_1 = require("./get-settings");
var main_window_1 = require("./main-window");
var os_1 = require("os");
var tray;
var DIR;
var shouldUseDarkColors;
var IS_MAC = process.platform === 'darwin';
var IS_LINUX = process.platform === 'linux';
var IS_WINDOWS = process.platform === 'win32';
var initIndicator = function (_a) {
    var showApp = _a.showApp, quitApp = _a.quitApp, app = _a.app, ICONS_FOLDER = _a.ICONS_FOLDER, forceDarkTray = _a.forceDarkTray;
    DIR = ICONS_FOLDER + 'indicator/';
    shouldUseDarkColors =
        forceDarkTray ||
            IS_LINUX ||
            (IS_WINDOWS && !isWindows11()) ||
            electron_1.nativeTheme.shouldUseDarkColors;
    initAppListeners(app);
    initListeners();
    var suf = shouldUseDarkColors ? '-d.png' : '-l.png';
    tray = new electron_1.Tray(DIR + "stopped".concat(suf));
    tray.setContextMenu(createContextMenu(showApp, quitApp));
    tray.on('click', function () {
        showApp();
    });
    return tray;
};
exports.initIndicator = initIndicator;
// eslint-disable-next-line prefer-arrow/prefer-arrow-functions
function initAppListeners(app) {
    if (tray) {
        app.on('before-quit', function () {
            if (tray) {
                tray.destroy();
            }
        });
    }
}
// eslint-disable-next-line prefer-arrow/prefer-arrow-functions
function initListeners() {
    electron_1.ipcMain.on(ipc_events_const_1.IPC.SET_PROGRESS_BAR, function (ev, _a) {
        var progress = _a.progress;
        var suf = shouldUseDarkColors ? '-d' : '-l';
        if (typeof progress === 'number' && progress > 0 && isFinite(progress)) {
            var f = Math.min(Math.round(progress * 15), 15);
            var t = DIR + "running-anim".concat(suf, "/").concat(f || 0, ".png");
            setTrayIcon(tray, t);
        }
        else {
            var t = DIR + "running".concat(suf, ".png");
            setTrayIcon(tray, t);
        }
    });
    electron_1.ipcMain.on(ipc_events_const_1.IPC.CURRENT_TASK_UPDATED, function (ev, currentTask) {
        var mainWin = (0, main_window_1.getWin)();
        (0, get_settings_1.getSettings)(mainWin, function (settings) {
            var isTrayShowCurrentTask = settings.misc.isTrayShowCurrentTask;
            var msg = isTrayShowCurrentTask && currentTask ? createIndicatorStr(currentTask) : '';
            if (tray) {
                // tray handling
                if (currentTask && currentTask.title) {
                    tray.setTitle(msg);
                    if (!IS_MAC) {
                        // NOTE apparently this has no effect for gnome
                        tray.setToolTip(msg);
                    }
                }
                else {
                    tray.setTitle('');
                    if (!IS_MAC) {
                        // NOTE apparently this has no effect for gnome
                        tray.setToolTip(msg);
                    }
                    var suf = shouldUseDarkColors ? '-d.png' : '-l.png';
                    setTrayIcon(tray, DIR + "stopped".concat(suf));
                }
            }
        });
    });
    // ipcMain.on(IPC.POMODORO_UPDATE, (ev, params) => {
    // const isOnBreak = params.isOnBreak;
    // const currentSessionTime = params.currentSessionTime;
    // const currentSessionInitialTime = params.currentSessionInitialTime;
    // if (isGnomeShellExtInstalled) {
    //  dbus.updatePomodoro(isOnBreak, currentSessionTime, currentSessionInitialTime);
    // }
    // });
}
// eslint-disable-next-line prefer-arrow/prefer-arrow-functions
function createIndicatorStr(task) {
    if (task && task.title) {
        var title = task.title;
        // let timeStr = '';
        // let msg;
        if (title.length > 40) {
            title = title.substring(0, 37) + '...';
        }
        return title;
        // if (task.timeSpent) {
        //   const timeSpentAsMinutes = Math.round(task.timeSpent / 60 / 1000);
        //   timeStr += timeSpentAsMinutes.toString();
        // }
        // const timeEstimateAsMin = Math.round(task.timeEstimate / 60 / 1000);
        //
        // if (task.timeEstimate && timeEstimateAsMin > 0) {
        //   timeStr += '/' + timeEstimateAsMin;
        // }
        //
        // msg = title + ' | ' + timeStr + 'm ';
        // return msg;
    }
    // NOTE: we need to make sure that this is always a string
    return '';
}
// eslint-disable-next-line prefer-arrow/prefer-arrow-functions
function createContextMenu(showApp, quitApp) {
    return electron_1.Menu.buildFromTemplate([
        {
            label: 'Show App',
            click: showApp,
        },
        {
            label: 'Quit',
            click: quitApp,
        },
    ]);
}
var curIco;
// eslint-disable-next-line prefer-arrow/prefer-arrow-functions
function setTrayIcon(tr, icoPath) {
    if (icoPath !== curIco) {
        curIco = icoPath;
        tr.setImage(icoPath);
    }
}
// eslint-disable-next-line prefer-arrow/prefer-arrow-functions
function isWindows11() {
    if (!IS_WINDOWS) {
        return false;
    }
    var v = (0, os_1.release)();
    var isWin11 = false;
    if (v.startsWith('11.')) {
        isWin11 = true;
    }
    else if (v.startsWith('10.')) {
        var ss = v.split('.');
        isWin11 = ss.length > 2 && parseInt(ss[2]) >= 22000 ? true : false;
    }
    return isWin11;
}
//# sourceMappingURL=indicator.js.map