"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWindow = exports.getIsAppReady = exports.getWin = void 0;
var windowStateKeeper = require("electron-window-state");
var electron_1 = require("electron");
var error_handler_with_frontend_inform_1 = require("./error-handler-with-frontend-inform");
var path = require("path");
var path_1 = require("path");
var url_1 = require("url");
var ipc_events_const_1 = require("./shared-with-frontend/ipc-events.const");
var get_settings_1 = require("./get-settings");
var fs_1 = require("fs");
var main_1 = require("electron-log/main");
var common_const_1 = require("./common.const");
var mainWin;
var mainWinModule = {
    win: undefined,
    isAppReady: false,
};
var getWin = function () {
    if (!mainWinModule.win) {
        throw new Error('No main window');
    }
    return mainWinModule.win;
};
exports.getWin = getWin;
var getIsAppReady = function () {
    return mainWinModule.isAppReady;
};
exports.getIsAppReady = getIsAppReady;
var createWindow = function (_a) {
    var IS_DEV = _a.IS_DEV, ICONS_FOLDER = _a.ICONS_FOLDER, quitApp = _a.quitApp, app = _a.app, customUrl = _a.customUrl;
    // make sure the main window isn't already created
    if (mainWin) {
        (0, error_handler_with_frontend_inform_1.errorHandlerWithFrontendInform)('Main window already exists');
        return mainWin;
    }
    // workaround for https://github.com/electron/electron/issues/16521
    if (!common_const_1.IS_MAC) {
        electron_1.Menu.setApplicationMenu(null);
    }
    var mainWindowState = windowStateKeeper({
        defaultWidth: 800,
        defaultHeight: 800,
    });
    mainWin = new electron_1.BrowserWindow({
        x: mainWindowState.x,
        y: mainWindowState.y,
        width: mainWindowState.width,
        height: mainWindowState.height,
        minHeight: 240,
        minWidth: 300,
        titleBarStyle: common_const_1.IS_MAC ? 'hidden' : 'default',
        show: false,
        webPreferences: {
            scrollBounce: true,
            backgroundThrottling: false,
            webSecurity: false,
            preload: path.join(__dirname, 'preload.js'),
            nodeIntegration: false,
            // make remote module work with those two settings
            contextIsolation: true,
        },
        icon: ICONS_FOLDER + '/icon_256x256.png',
    });
    // see: https://pratikpc.medium.com/bypassing-cors-with-electron-ab7eaf331605
    mainWin.webContents.session.webRequest.onBeforeSendHeaders(function (details, callback) {
        var requestHeaders = details.requestHeaders;
        removeKeyInAnyCase(requestHeaders, 'Origin');
        removeKeyInAnyCase(requestHeaders, 'Referer');
        removeKeyInAnyCase(requestHeaders, 'Cookie');
        removeKeyInAnyCase(requestHeaders, 'sec-ch-ua');
        removeKeyInAnyCase(requestHeaders, 'sec-ch-ua-mobile');
        removeKeyInAnyCase(requestHeaders, 'sec-ch-ua-platform');
        removeKeyInAnyCase(requestHeaders, 'sec-fetch-dest');
        removeKeyInAnyCase(requestHeaders, 'sec-fetch-mode');
        removeKeyInAnyCase(requestHeaders, 'sec-fetch-site');
        removeKeyInAnyCase(requestHeaders, 'accept-encoding');
        removeKeyInAnyCase(requestHeaders, 'accept-language');
        removeKeyInAnyCase(requestHeaders, 'priority');
        removeKeyInAnyCase(requestHeaders, 'accept');
        // NOTE this is needed for GitHub api requests to work :(
        if (!details.url.includes('github.com')) {
            removeKeyInAnyCase(requestHeaders, 'User-Agent');
        }
        callback({ requestHeaders: requestHeaders });
    });
    mainWin.webContents.session.webRequest.onHeadersReceived(function (details, callback) {
        var responseHeaders = details.responseHeaders;
        upsertKeyValue(responseHeaders, 'Access-Control-Allow-Origin', ['*']);
        upsertKeyValue(responseHeaders, 'Access-Control-Allow-Headers', ['*']);
        upsertKeyValue(responseHeaders, 'Access-Control-Allow-Methods', ['*']);
        callback({
            responseHeaders: responseHeaders,
        });
    });
    mainWindowState.manage(mainWin);
    var url = customUrl
        ? customUrl
        : IS_DEV
            ? 'http://localhost:4200'
            : (0, url_1.format)({
                pathname: (0, path_1.normalize)((0, path_1.join)(__dirname, '../dist/browser/index.html')),
                protocol: 'file:',
                slashes: true,
            });
    mainWin.loadURL(url).then(function () {
        // load custom stylesheet if any
        var CSS_FILE_PATH = app.getPath('userData') + '/styles.css';
        (0, fs_1.stat)(app.getPath('userData') + '/styles.css', function (err) {
            if (err) {
                (0, main_1.log)('No custom styles detected at ' + CSS_FILE_PATH);
            }
            else {
                (0, main_1.log)('Loading custom styles from ' + CSS_FILE_PATH);
                var styles = (0, fs_1.readFileSync)(CSS_FILE_PATH, { encoding: 'utf8' });
                mainWin.webContents.insertCSS(styles).then(main_1.log).catch(main_1.error);
            }
        });
    });
    // show gracefully
    mainWin.once('ready-to-show', function () {
        mainWin.show();
    });
    initWinEventListeners(app);
    if (common_const_1.IS_MAC) {
        createMenu(quitApp);
    }
    else {
        mainWin.setMenu(null);
        mainWin.setMenuBarVisibility(false);
    }
    // update prop
    mainWinModule.win = mainWin;
    // listen for app ready
    electron_1.ipcMain.on(ipc_events_const_1.IPC.APP_READY, function () {
        mainWinModule.isAppReady = true;
    });
    return mainWin;
};
exports.createWindow = createWindow;
// eslint-disable-next-line prefer-arrow/prefer-arrow-functions
function initWinEventListeners(app) {
    var openUrlInBrowser = function (url) {
        // needed for mac; especially for jira urls we might have a host like this www.host.de//
        var urlObj = new URL(url);
        urlObj.pathname = urlObj.pathname.replace('//', '/');
        var wellFormedUrl = urlObj.toString();
        var wasOpened = electron_1.shell.openExternal(wellFormedUrl);
        if (!wasOpened) {
            electron_1.shell.openExternal(wellFormedUrl);
        }
    };
    // open new window links in browser
    mainWin.webContents.on('will-navigate', function (ev, url) {
        if (!url.includes('localhost')) {
            ev.preventDefault();
            openUrlInBrowser(url);
        }
    });
    mainWin.webContents.setWindowOpenHandler(function (details) {
        openUrlInBrowser(details.url);
        return { action: 'deny' };
    });
    // TODO refactor quitting mess
    appCloseHandler(app);
    appMinimizeHandler(app);
}
// eslint-disable-next-line prefer-arrow/prefer-arrow-functions
function createMenu(quitApp) {
    // Create application menu to enable copy & pasting on MacOS
    var menuTpl = [
        {
            label: 'Application',
            submenu: [
                { label: 'About Super Productivity', selector: 'orderFrontStandardAboutPanel:' },
                { type: 'separator' },
                {
                    label: 'Quit',
                    click: quitApp,
                    accelerator: 'CmdOrCtrl+Q',
                },
            ],
        },
        {
            label: 'Edit',
            submenu: [
                { label: 'Undo', accelerator: 'CmdOrCtrl+Z', selector: 'undo:' },
                { label: 'Redo', accelerator: 'Shift+CmdOrCtrl+Z', selector: 'redo:' },
                { type: 'separator' },
                { label: 'Cut', accelerator: 'CmdOrCtrl+X', selector: 'cut:' },
                { label: 'Copy', accelerator: 'CmdOrCtrl+C', selector: 'copy:' },
                { label: 'Paste', accelerator: 'CmdOrCtrl+V', selector: 'paste:' },
                { label: 'Select All', accelerator: 'CmdOrCtrl+A', selector: 'selectAll:' },
            ],
        },
    ];
    var menuTplOUT = menuTpl;
    // we need to set a menu to get copy & paste working for mac os x
    electron_1.Menu.setApplicationMenu(electron_1.Menu.buildFromTemplate(menuTplOUT));
}
// TODO this is ugly as f+ck
var appCloseHandler = function (app) {
    var ids = [];
    var _quitApp = function () {
        app.isQuiting = true;
        mainWin.close();
    };
    electron_1.ipcMain.on(ipc_events_const_1.IPC.REGISTER_BEFORE_CLOSE, function (ev, _a) {
        var id = _a.id;
        ids.push(id);
    });
    electron_1.ipcMain.on(ipc_events_const_1.IPC.UNREGISTER_BEFORE_CLOSE, function (ev, _a) {
        var id = _a.id;
        ids = ids.filter(function (idIn) { return idIn !== id; });
    });
    electron_1.ipcMain.on(ipc_events_const_1.IPC.BEFORE_CLOSE_DONE, function (ev, _a) {
        var id = _a.id;
        ids = ids.filter(function (idIn) { return idIn !== id; });
        (0, main_1.log)(ipc_events_const_1.IPC.BEFORE_CLOSE_DONE, id, ids);
        if (ids.length === 0) {
            mainWin.close();
        }
    });
    mainWin.on('close', function (event) {
        // NOTE: this might not work if we run a second instance of the app
        (0, main_1.log)('close, isQuiting:', app.isQuiting);
        if (!app.isQuiting) {
            event.preventDefault();
            (0, get_settings_1.getSettings)(mainWin, function (appCfg) {
                if (appCfg && appCfg.misc.isMinimizeToTray && !app.isQuiting) {
                    mainWin.hide();
                    return;
                }
                if (ids.length > 0) {
                    (0, main_1.log)('Actions to wait for ', ids);
                    mainWin.webContents.send(ipc_events_const_1.IPC.NOTIFY_ON_CLOSE, ids);
                }
                else {
                    _quitApp();
                }
            });
        }
    });
    mainWin.webContents.on('render-process-gone', function (event, detailed) {
        (0, main_1.log)('!crashed, reason: ' + detailed.reason + ', exitCode = ' + detailed.exitCode);
        if (detailed.reason == 'crashed') {
            process.exit(detailed.exitCode);
            // relaunch app
            // app.relaunch({ args: process.argv.slice(1).concat(['--relaunch']) });
            // app.exit(0);
        }
    });
};
var appMinimizeHandler = function (app) {
    if (!app.isQuiting) {
        // TODO find reason for the typing error
        // @ts-ignore
        mainWin.on('minimize', function (event) {
            (0, get_settings_1.getSettings)(mainWin, function (appCfg) {
                if (appCfg.misc.isMinimizeToTray) {
                    event.preventDefault();
                    mainWin.hide();
                }
                else if (common_const_1.IS_MAC) {
                    app.dock.show();
                }
            });
        });
    }
};
var upsertKeyValue = function (obj, keyToChange, value) {
    var keyToChangeLower = keyToChange.toLowerCase();
    for (var _i = 0, _a = Object.keys(obj); _i < _a.length; _i++) {
        var key = _a[_i];
        if (key.toLowerCase() === keyToChangeLower) {
            // Reassign old key
            obj[key] = value;
            // Done
            return;
        }
    }
    // Insert at end instead
    obj[keyToChange] = value;
};
var removeKeyInAnyCase = function (obj, keyToRemove) {
    var keyToRemoveLower = keyToRemove.toLowerCase();
    for (var _i = 0, _a = Object.keys(obj); _i < _a.length; _i++) {
        var key = _a[_i];
        if (key.toLowerCase() === keyToRemoveLower) {
            delete obj[key];
            return;
        }
    }
};
//# sourceMappingURL=main-window.js.map