"use strict";
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
var electron_1 = require("electron");
var _send = function (channel) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    return electron_1.ipcRenderer.send.apply(electron_1.ipcRenderer, __spreadArray([channel], args, false));
};
var _invoke = function (channel) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    return electron_1.ipcRenderer.invoke.apply(electron_1.ipcRenderer, __spreadArray([channel], args, false));
};
var ea = {
    on: function (channel, listener) {
        // NOTE: there is no proper way to unsubscribe apart from unsubscribing all
        electron_1.ipcRenderer.on(channel, listener);
    },
    // INVOKE
    // ------
    getUserDataPath: function () { return _invoke('GET_PATH', 'userData'); },
    getBackupPath: function () { return _invoke('GET_BACKUP_PATH'); },
    checkBackupAvailable: function () {
        return _invoke('BACKUP_IS_AVAILABLE');
    },
    loadBackupData: function (backupPath) {
        return _invoke('BACKUP_LOAD_DATA', backupPath);
    },
    fileSyncGetRevAndClientUpdate: function (backupPath) {
        return _invoke('FILE_SYNC_GET_REV_AND_CLIENT_UPDATE', backupPath);
    },
    fileSyncSave: function (filePath) {
        return _invoke('FILE_SYNC_SAVE', filePath);
    },
    fileSyncLoad: function (filePath) {
        return _invoke('FILE_SYNC_LOAD', filePath);
    },
    checkDirExists: function (dirPath) {
        return _invoke('CHECK_DIR_EXISTS', dirPath);
    },
    pickDirectory: function () { return _invoke('PICK_DIRECTORY'); },
    // STANDARD
    // --------
    setZoomFactor: function (zoomFactor) {
        electron_1.webFrame.setZoomFactor(zoomFactor);
    },
    getZoomFactor: function () { return electron_1.webFrame.getZoomFactor(); },
    isLinux: function () { return process.platform === 'linux'; },
    isMacOS: function () { return process.platform === 'darwin'; },
    isSnap: function () { return process && process.env && !!process.env.SNAP; },
    // SEND
    // ----
    relaunch: function () { return _send('RELAUNCH'); },
    exit: function () { return _send('EXIT'); },
    flashFrame: function () { return _send('FLASH_FRAME'); },
    showOrFocus: function () { return _send('SHOW_OR_FOCUS'); },
    lockScreen: function () { return _send('LOCK_SCREEN'); },
    shutdownNow: function () { return _send('SHUTDOWN_NOW'); },
    reloadMainWin: function () { return _send('RELOAD_MAIN_WIN'); },
    openDevTools: function () { return _send('OPEN_DEV_TOOLS'); },
    showEmojiPanel: function () { return _send('SHOW_EMOJI_PANEL'); },
    informAboutAppReady: function () { return _send('APP_READY'); },
    openPath: function (path) { return _send('OPEN_PATH', path); },
    openExternalUrl: function (url) { return _send('OPEN_EXTERNAL', url); },
    scheduleRegisterBeforeClose: function (id) { return _send('REGISTER_BEFORE_CLOSE', { id: id }); },
    unscheduleRegisterBeforeClose: function (id) { return _send('UNREGISTER_BEFORE_CLOSE', { id: id }); },
    setDoneRegisterBeforeClose: function (id) { return _send('BEFORE_CLOSE_DONE', { id: id }); },
    setProgressBar: function (args) { return _send('SET_PROGRESS_BAR', args); },
    sendAppSettingsToElectron: function (globalCfg) {
        return _send('TRANSFER_SETTINGS_TO_ELECTRON', globalCfg);
    },
    registerGlobalShortcuts: function (keyboardCfg) {
        return _send('REGISTER_GLOBAL_SHORTCUTS', keyboardCfg);
    },
    showFullScreenBlocker: function (args) { return _send('FULL_SCREEN_BLOCKER', args); },
    makeJiraRequest: function (args) { return _send('JIRA_MAKE_REQUEST_EVENT', args); },
    jiraSetupImgHeaders: function (args) { return _send('JIRA_SETUP_IMG_HEADERS', args); },
    backupAppData: function (appData) { return _send('BACKUP', appData); },
    updateCurrentTask: function (task) { return _send('CURRENT_TASK_UPDATED', task); },
    exec: function (command) { return _send('EXEC', command); },
};
electron_1.contextBridge.exposeInMainWorld('ea', ea);
// contextBridge.exposeInIsolatedWorld();
console.log('preload script loading complete');
//# sourceMappingURL=preload.js.map